# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['palme']

package_data = \
{'': ['*']}

install_requires = \
['einops', 'torch', 'zetascale']

setup_kwargs = {
    'name': 'palme',
    'version': '0.1.2',
    'description': 'palme - Pytorch',
    'long_description': '[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)\n\n\n# 🌴 PALM-E: A Multi-Modal AI Model \n![model architecture](image6.png)\n\n\nThis is the open source implementation of the SOTA multi-modality foundation model "PALM-E: An Embodied Multimodal Language Model" from Google, PALM-E is a single large embodied multimodal model, that can address a variety of embodied reasoning tasks, from a variety of observation modalities, on multiple embodiments, and further, exhibits positive transfer: the model benefits from diverse joint training across internet-scale language, vision, and visual-language domains.\n\n[PAPER LINK: PaLM-E: An Embodied Multimodal Language Model](https://arxiv.org/abs/2303.03378)\n\n\n\n[![GitHub issues](https://img.shields.io/github/issues/kyegomez/PALM-E)](https://github.com/kyegomez/PALM-E/issues) \n[![GitHub forks](https://img.shields.io/github/forks/kyegomez/PALM-E)](https://github.com/kyegomez/PALM-E/network) \n[![GitHub stars](https://img.shields.io/github/stars/kyegomez/PALM-E)](https://github.com/kyegomez/PALM-E/stargazers) [![GitHub license](https://img.shields.io/github/license/kyegomez/PALM-E)](https://github.com/kyegomez/PALM-E/blob/master/LICENSE)\n[![Share on Twitter](https://img.shields.io/twitter/url/https/twitter.com/cloudposse.svg?style=social&label=Share%20%40kyegomez/PALM-E)](https://twitter.com/intent/tweet?text=Excited%20to%20introduce%20PALM-E,%20the%20all-new%20Multi-Modal%20model%20with%20the%20potential%20to%20revolutionize%20automation.%20Join%20us%20on%20this%20journey%20towards%20a%20smarter%20future.%20%23PALM-E%20%23Multi-Modal&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2FPALM-E)\n[![Share on Facebook](https://img.shields.io/badge/Share-%20facebook-blue)](https://www.facebook.com/sharer/sharer.php?u=https%3A%2F%2Fgithub.com%2Fkyegomez%2FPALM-E)\n[![Share on LinkedIn](https://img.shields.io/badge/Share-%20linkedin-blue)](https://www.linkedin.com/shareArticle?mini=true&url=https%3A%2F%2Fgithub.com%2Fkyegomez%2FPALM-E&title=Introducing%20PALM-E%2C%20the%20All-New%20Multi-Modal%20Model&summary=PALM-E%20is%20the%20next-generation%20Multi-Modal%20model%20that%20promises%20to%20transform%20industries%20with%20its%20intelligence%20and%20efficiency.%20Join%20us%20to%20be%20a%20part%20of%20this%20revolutionary%20journey%20%23PALM-E%20%23Multi-Modal&source=)\n![Discord](https://img.shields.io/discord/999382051935506503)\n[![Share on Reddit](https://img.shields.io/badge/-Share%20on%20Reddit-orange)](https://www.reddit.com/submit?url=https%3A%2F%2Fgithub.com%2Fkyegomez%2FPALM-E&title=Exciting%20Times%20Ahead%20with%20PALM-E%2C%20the%20All-New%20Multi-Modal%20Model%20%23PALM-E%20%23Multi-Modal) [![Share on Hacker News](https://img.shields.io/badge/-Share%20on%20Hacker%20News-orange)](https://news.ycombinator.com/submitlink?u=https%3A%2F%2Fgithub.com%2Fkyegomez%2FPALM-E&t=Exciting%20Times%20Ahead%20with%20PALM-E%2C%20the%20All-New%20Multi-Modal%20Model%20%23PALM-E%20%23Multi-Modal)\n[![Share on Pinterest](https://img.shields.io/badge/-Share%20on%20Pinterest-red)](https://pinterest.com/pin/create/button/?url=https%3A%2F%2Fgithub.com%2Fkyegomez%2FPALM-E&media=https%3A%2F%2Fexample.com%2Fimage.jpg&description=PALM-E%2C%20the%20Revolutionary%20Multi-Modal%20Model%20that%20will%20Change%20the%20Way%20We%20Work%20%23PALM-E%20%23Multi-Modal)\n[![Share on WhatsApp](https://img.shields.io/badge/-Share%20on%20WhatsApp-green)](https://api.whatsapp.com/send?text=I%20just%20discovered%20PALM-E,%20the%20all-new%20Multi-Modal%20model%20that%20promises%20to%20revolutionize%20automation.%20Join%20me%20on%20this%20exciting%20journey%20towards%20a%20smarter%20future.%20%23PALM-E%20%23Multi-Modal%0A%0Ahttps%3A%2F%2Fgithub.com%2Fkyegomez%2FPALM-E)\n\n## Note\n- This is just the model architecture, no pretrained weights, no tokenizer\n- To actually conduct inference you would need to --> setup tokenizer for text and images -> train -> inference\n- If you are doing research into multi modal models and would like to train this model and release it open source join the agora lab by clicking on the banner!\n\n## Appreciation\n* All the creators in Agora, [Join Agora](https://discord.gg/qUtxnK2NMf) the community of AI engineers changing the world with their creations.\n* LucidRains for inspiring me to devote myself to open source AI\n\n\n## 🚀 Quick Start\n\n### Installation 📦\n\n```sh\npip install palme\n```\n\n### Usage 🎨\n\n```python\nimport torch\nfrom palme.model import PalmE\n\n#usage\nimg = torch.randn(1, 3, 256, 256)\ncaption = torch.randint(0, 20000, (1, 1024))\n\nmodel = PalmE()\noutput = model(img, caption)\nprint(output.shape) # (1, 1024, 20000)\n\n\n\n```\n---\n\n# Training\nHere is a summary table of the key training hyperparameters mentioned in the paper:\n\n| Hyperparameter | Value |  \n|-|-|\n| Batch size | 2048 |\n| Learning rate | 1.5e-4  |\n| Warmup steps | 10,000 |\n| Gradient accumulation steps | 4 |\n| Weight decay | 0.01 |\n| Dropout rate | 0.1 |\n| Embedding dropout rate | 0.1 |\n| Attention dropout rate | 0.1 |\n| Optimizer | AdamW |\n| Gradient clipping | 1.0 |\n\nThe key details are:\n- Batch size of 2048 \n- Learning rate of 1.5e-4 with 10k warmup steps\n- AdamW optimizer\n- Dropout of 0.1 on embeddings, attention, and full model\n- Weight decay of 0.01\n- Gradient clipping of 1.0\n\nThey used a fairly standard transformer hyperparameters configuration. The large batch size and gradient accumulation allows them to train huge models.\n\n1. Set the environment variables:\n   - `ENTITY_NAME`: Your wandb project name\n   - `OUTPUT_DIR`: Directory to save the weights (e.g., `./weights`)\n   - `MASTER_ADDR`: For distributed training\n   - `MASTER_PORT` For master port distributed training\n   - `RANK`- Number of nodes services\n   - `WORLD_SIZE` Number of gpus\n\n2. Configure the training:\n   - Accelerate Config\n   - Enable Deepspeed 3\n   - Accelerate launch train.py\n\nFor more information, refer to the [Training SOP](DOCs/TRAINING.md).\n\n---\n\n# Dataset Strategy\nHere is a summary table of the key datasets mentioned in the paper:\n\n| Dataset | Tasks | Size | Link |\n|-|-|-|-|  \n| TAMP | Robotic manipulation planning, VQA | 96,000 scenes | Custom dataset |\n| Language Table | Robotic manipulation planning | Custom dataset | [Link](https://github.com/google-research/language-table) |  \n| Mobile Manipulation | Robotic navigation and manipulation planning, VQA | 2912 sequences | Based on SayCan dataset |\n| WebLI | Image-text retrieval | 66M image-caption pairs | [Link](https://arxiv.org/abs/2209.06794) |\n| VQAv2 | Visual question answering | 1.1M questions on COCO images | [Link](https://visualqa.org/) |  \n| OK-VQA | Visual question answering requiring external knowledge | 14,031 questions on COCO images | [Link](https://allenai.org/data/ok-vqa) |\n| COCO | Image captioning | 330K images with captions | [Link](https://cocodataset.org/) |\n| Wikipedia | Text corpus | N/A | [Link](https://en.wikipedia.org) |\n\nThe key robotics datasets were collected specifically for this work, while the larger vision-language datasets (WebLI, VQAv2, OK-VQA, COCO) are standard benchmarks in that field. The datasets range from tens of thousands of examples for the robotics domains to tens of millions for the internet-scale vision-language data.\n\n---\n\n## Contribute || Be Part of the PALM-E Adventure 🤝\n\nYour brilliance is needed! Join us, and together, let\'s make PALM-E even more awe-inspiring:\n\n1. **Get Your Copy**: Fork the PALM-E repo.\n2. **Make It Local**: Clone your fork.\n3. **Prep Your Tools**: Install the necessities.\n4. **Discover & Innovate**: Dive into the code.\n5. **Craft Your Magic**: Branch and code away.\n6. **Show & Tell**: Push your changes and craft a pull request.\n\n🐞 Fixes, 🎨 enhancements, 📝 docs, or 💡 ideas – all are welcome! Let\'s shape the future of AI, hand in hand.\n\n---\n\n## Citation\n```latex\n@article{driess2023palme,\n  title={PALM-E: An Embodied Multimodal Language Model},\n  author={Driess, Danny and Xia, Fei and Sajjadi, Mehdi S. M. and Lynch, Corey and Chowdhery, Aakanksha and Ichter, Brian and Wahid, Ayzaan and Tompson, Jonathan and Vuong, Quan and Yu, Tianhe and Huang, Wenlong and Chebotar, Yevgen and Sermanet, Pierre and Duckworth, Daniel and Levine, Sergey and Vanhoucke, Vincent and Hausman, Karol and Toussaint, Marc and Greff, Klaus and Zeng, Andy and Mordatch, Igor and Florence, Pete},\n  journal={arXiv preprint arXiv:2303.03378},\n  year={2023},\n  url={https://doi.org/10.48550/arXiv.2303.03378}\n}\n```\n\n-----\n\n## Roadmap\n\n- [ ] URGENT: Debug Tokenizer, make sure multi-modal inputs work. \n- [ ] Create Dataset Strategy\n- [ ] Upload Training Documentation\n- [ ] Get Training running with multi-modal\n\n---\n',
    'author': 'Kye Gomez',
    'author_email': 'kye@apac.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/kyegomez/palme',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
